package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.ui.internal.ControlFactory;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.core.runtime.Assert;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Layout;

public class RadioButtonsArea extends Composite {
  private String[][] labelsAndValues;
  
  private int numColumns;
  
  protected String value = null;
  
  private SelectionListener listener;
  
  private List<SelectionListener> externalListeners = new ArrayList<>();
  
  private Composite area = null;
  
  protected Button[] radioButtons;
  
  public RadioButtonsArea(Composite parent, String labelText, int numColumns, String[][] labelAndValues) {
    super(parent, 0);
    Assert.isTrue(checkArray(labelAndValues));
    this.labelsAndValues = (String[][])labelAndValues.clone();
    this.numColumns = numColumns;
    createControl(parent, labelText);
  }
  
  public void setEnabled(boolean enabled) {
    for (Button radioButton : this.radioButtons)
      radioButton.setEnabled(enabled); 
  }
  
  private boolean checkArray(String[][] table) {
    if (table == null)
      return false; 
    for (String[] array : table) {
      if (array == null || array.length != 2)
        return false; 
    } 
    return true;
  }
  
  protected void fireSelectionEvent(SelectionEvent event) {
    for (SelectionListener s : this.externalListeners)
      s.widgetSelected(event); 
  }
  
  protected void createControl(Composite parent, String labelText) {
    GridLayout gl = new GridLayout();
    setLayoutData(new GridData(768));
    gl.marginWidth = 0;
    gl.horizontalSpacing = 0;
    setLayout((Layout)gl);
    if (labelText != null) {
      this.area = (Composite)ControlFactory.createGroup(this, labelText, this.numColumns);
    } else {
      gl.numColumns = this.numColumns;
      this.area = this;
    } 
    this.radioButtons = new Button[this.labelsAndValues.length];
    this.listener = (SelectionListener)new Object(this);
    for (int i = 0; i < this.labelsAndValues.length; i++)
      this.radioButtons[i] = ControlFactory.createRadioButton(this.area, this.labelsAndValues[i][0], this.labelsAndValues[i][1], this.listener); 
    this.area.addDisposeListener((DisposeListener)new Object(this));
  }
  
  public void setIndent(int indent) {
    if (null == this.area)
      return; 
    if (indent < 0)
      indent = 0; 
    for (int i = 0; i < this.radioButtons.length; i++)
      ((GridData)this.radioButtons[i].getLayoutData()).horizontalIndent = indent; 
  }
  
  public void setSelectValue(String selectedValue) {
    this.value = selectedValue;
    if (this.radioButtons == null)
      return; 
    if (this.value != null) {
      boolean found = false;
      for (Button radio : this.radioButtons) {
        boolean selection = false;
        if (radio.getData().equals(this.value)) {
          selection = true;
          found = true;
        } 
        radio.setSelection(selection);
      } 
      if (found)
        return; 
    } 
    if (this.radioButtons.length > 0) {
      this.radioButtons[0].setSelection(true);
      this.value = (String)this.radioButtons[0].getData();
    } 
  }
  
  public void setSelectedButton(int index) {
    if (index < 0 || index >= this.radioButtons.length)
      return; 
    for (int i = 0; i < this.radioButtons.length; i++) {
      Button button = this.radioButtons[i];
      boolean selected = button.getSelection();
      if (i == index) {
        if (selected)
          return; 
      } else if (selected) {
        button.setSelection(false);
      } 
    } 
    Button b = this.radioButtons[index];
    this.value = (String)b.getData();
    b.setSelection(true);
  }
  
  public String getSelectedValue() {
    return this.value;
  }
  
  public int getSeletedIndex() {
    if (this.radioButtons == null)
      return -1; 
    if (this.value != null)
      for (int i = 0; i < this.radioButtons.length; i++) {
        if (this.radioButtons[i].getData().equals(this.value))
          return i; 
      }  
    return -1;
  }
  
  public void addSelectionListener(SelectionListener s) {
    if (this.externalListeners.contains(s))
      return; 
    this.externalListeners.add(s);
  }
}
